@@ -1,24 +1,23 @@
-import itertools
 import json
 import logging
 import math
 import os
 import string
+import time
 from datetime import datetime
 from mimetypes import types_map
+from urllib.parse import urljoin, quote
 
 import bs4
 import requests
 from django.conf import settings
-from django.contrib.gis.gdal.error import OGRException
+from django.contrib.gis.gdal.error import GDALException
 from django.contrib.gis.geos import GEOSException, fromstr
-from django.urls import resolve
 from django.http import HttpResponse
 from django.template.exceptions import TemplateDoesNotExist
 from django.template.loader import get_template
-from django.utils import six
+from django.urls import resolve
 from django.utils import timezone
-from django.utils.six.moves.urllib.parse import urljoin, quote
 from django.utils.translation import get_language
 
 from .settings import app_settings, API_SRID
@@ -26,40 +25,6 @@ from .settings import app_settings, API_SRID
 logger = logging.getLogger(__name__)
 
 
-def bbox_split(bbox, by_x=2, by_y=2, cycle=False):
-    """Divide a box in rectangle, by_x parts and by_y parts"""
-    minx, miny, maxx, maxy = bbox
-
-    stepx = (maxx - minx) / by_x
-    stepy = (maxy - miny) / by_y
-
-    def gen():
-        """define as inner function to decorate it with cycle"""
-        stepx_tmp = minx
-        while stepx_tmp + stepx <= maxx:
-            stepx_next = stepx_tmp + stepx
-
-            stepy_tmp = miny
-            while stepy_tmp + stepy <= maxy:
-                stepy_next = stepy_tmp + stepy
-                yield (stepx_tmp, stepy_tmp, stepx_next, stepy_next)
-
-                stepy_tmp = stepy_next
-
-            stepx_tmp = stepx_next
-
-    if cycle:
-        return itertools.cycle(gen())
-    else:
-        return gen()
-
-
-def bbox_split_srid_2154(*args, **kwargs):
-    """Just round"""
-    gen = bbox_split(*args, **kwargs)
-    return iter(lambda: map(round, gen.next()), None)
-
-
 def api_bbox(bbox, srid=None, buffer=0.0):
     """ Receives a tuple(xmin, ymin, xmax, ymax) and
     returns a tuple in API projection.
@@ -85,34 +50,12 @@ def wkt_to_geom(wkt, srid_from=None, silent=False):
         srid_from = API_SRID
     try:
         return fromstr(wkt, srid=srid_from)
-    except (OGRException, GEOSException) as e:
+    except (GDALException, GEOSException) as e:
         if not silent:
             raise e
         return None
 
 
-def transform_wkt(wkt, srid_from=None, srid_to=None, dim=3):
-    """
-    Changes SRID, and returns 3D wkt
-    """
-    if srid_from is None:
-        srid_from = API_SRID
-    if srid_to is None:
-        srid_to = settings.SRID
-    try:
-        geom = fromstr(wkt, srid=srid_from)
-        if srid_from != srid_to:
-            geom.transform(srid_to)
-        extracoords = ' 0.0' * (dim - 2)  # add missing dimensions
-        wkt3d = geom.wkt.replace(',', extracoords + ',')
-        wkt3d = wkt3d.replace(')', extracoords + ')')
-        return 'SRID=%s;%s' % (srid_to, wkt3d)
-    except (OGRException, GEOSException, TypeError, ValueError) as e:
-        if settings.DEBUG or not getattr(settings, 'TEST', False):
-            logger.error("wkt_to_geom('%s', %s, %s) : %s" % (wkt, srid_from, srid_to, e))
-        return None
-
-
 def smart_urljoin(base, path):
     if base[-1] != '/':
         base += '/'
@@ -121,7 +64,7 @@ def smart_urljoin(base, path):
     return urljoin(base, path)
 
 
-def is_file_newer(path, date_update, delete_empty=True):
+def is_file_uptodate(path, date_update, delete_empty=True):
     if not os.path.exists(path):
         return False
 
@@ -138,27 +81,35 @@ def is_file_newer(path, date_update, delete_empty=True):
     return modified > date_update
 
 
+def get_source(url, headers):
+    logger.info("Request to: %s" % url)
+    source = requests.get(url, headers=headers)
+
+    status_error = 'Request on %s failed (status=%s)' % (url, source.status_code)
+    assert source.status_code == 200, status_error
+
+    content_error = 'Request on %s returned empty content' % url
+    assert len(source.content) > 0, content_error
+
+    return source
+
+
 def download_to_stream(url, stream, silent=False, headers=None):
     """ Download url and writes response to stream.
     """
     source = None
 
     try:
-
-        logger.info("Request to: %s" % url)
-        source = requests.get(url, headers=headers)
-
-        status_error = 'Request on %s failed (status=%s)' % (url, source.status_code)
-        assert source.status_code == 200, status_error
-
-        content_error = 'Request on %s returned empty content' % url
-        assert len(source.content) > 0, content_error
-
+        try:
+            source = get_source(url, headers)
+        except requests.exceptions.ConnectionError:
+            time.sleep(1)
+            source = get_source(url, headers)
     except (AssertionError, requests.exceptions.RequestException) as e:
         logger.exception(e)
         logger.info('Headers sent: %s' % headers)
-        if hasattr(source, 'content'):
-            logger.info('Response: %s' % source.content[:150])
+        if hasattr(source, 'text'):
+            logger.info('Response: %s' % source.text[:150])
 
         if not silent:
             raise
@@ -203,11 +154,12 @@ def convertit_url(url, from_type=None, to_type=None, proxy=False):
 def convertit_download(url, destination, from_type=None, to_type='application/pdf', headers=None):
     # Mock for tests
     if getattr(settings, 'TEST', False):
-        open(destination, 'wb').write("Mock\n")
-        return
+        with open(destination, 'w') as out_file:
+            out_file.write("Mock\n")
+            return
 
     url = convertit_url(url, from_type, to_type)
-    fd = open(destination, 'wb') if isinstance(destination, six.string_types) else destination
+    fd = open(destination, 'wb') if isinstance(destination, str) else destination
     download_to_stream(url, fd, headers=headers)
 
 
@@ -294,7 +246,7 @@ def extract_attributes_html(url, request):
     for a in details('a'):
         a.replaceWith(a.text)
     # Prettify (ODT compat.) and convert unicode to XML entities
-    cooked = details.prettify('ascii', formatter='html')
+    cooked = details.prettify('ascii', formatter='html').decode()
     return cooked
 
 
@@ -302,7 +254,7 @@ def user_has_perm(user, perm):
     # First check if the user has the permission (even anon user)
     if user.has_perm(perm):
         return True
-    if user.is_anonymous():
+    if user.is_anonymous:
         return perm in app_settings['ANONYMOUS_VIEWS_PERMS']
     return False
 
@@ -318,7 +270,7 @@ def alphabet_enumeration(length):
         return ["A"]
     width = int(math.ceil(math.log(length, 26)))
     enums = []
-    alphabet = string.lowercase.upper()
+    alphabet = string.ascii_uppercase
     for i in range(length):
         enum = ""
         for j in range(width):
