@@ -1,5 +1,6 @@
 from .commasv import CSVSerializer
 from .datatables import MapentityDatatableSerializer
+from .geojson import MapentityGeojsonModelSerializer, MapentityGeojsonModelListSerializer
 from .gpx import GPXSerializer
 from .helpers import json_django_dumps, plain_text, smart_plain_text
 from .shapefile import ZipShapeSerializer
@@ -9,5 +10,7 @@ __all__ = ['plain_text',
            'CSVSerializer',
            'GPXSerializer',
            'MapentityDatatableSerializer',
+           'MapentityGeojsonModelSerializer',
+           'MapentityGeojsonModelListSerializer',
            'ZipShapeSerializer',
            'json_django_dumps']
